@@ -120,7 +120,15 @@ impl TypedBuffer for IndexBuffer {
         element_size: Bytes,
     ) -> Self {
         let size = element_size * element_count;
-        let view = IndexBufferView::new(&buffer, element_count, element_size);
+        let view = IndexBufferView::default()
+            .set_buffer_location(buffer.get_gpu_virtual_address())
+            .set_size_in_bytes(element_count * element_size)
+            .set_format(match element_size {
+                Bytes(2) => Format::R16_UInt,
+                Bytes(4) => Format::R32_UInt,
+                _ => panic!("wrong index type"),
+            });
+
         IndexBuffer {
             buffer: buffer,
             view: view,
@@ -176,7 +184,7 @@ impl HelloTriangleSample {
             .expect("Cannot create fence");
 
         let rtv_descriptor_size = device
-            .get_descriptor_handle_increment_size(DescriptorHeapType::RTV);
+            .get_descriptor_handle_increment_size(DescriptorHeapType::Rtv);
 
         let command_queue = device
             .create_command_queue(&CommandQueueDesc::default())
@@ -211,7 +219,7 @@ impl HelloTriangleSample {
         let rtv_heap = device
             .create_descriptor_heap(
                 &DescriptorHeapDesc::default()
-                    .set_heap_type(DescriptorHeapType::RTV)
+                    .set_heap_type(DescriptorHeapType::Rtv)
                     .set_num_descriptors(FRAMES_IN_FLIGHT),
             )
             .expect("Cannot create RTV heap");
@@ -384,7 +392,7 @@ float4 PS(VertexOut input) : SV_Target
         HelloTriangleSample::add_transition(
             &self.command_list,
             &current_buffer,
-            ResourceStates::CommonOrPresent,
+            ResourceStates::Common,
             ResourceStates::RenderTarget,
         );
 
@@ -429,7 +437,7 @@ float4 PS(VertexOut input) : SV_Target
             &self.command_list,
             &current_buffer,
             ResourceStates::RenderTarget,
-            ResourceStates::CommonOrPresent,
+            ResourceStates::Common,
         );
 
         self.command_list
@@ -566,7 +574,7 @@ impl HelloTriangleSample {
                 &self.device,
                 size,
                 HeapType::Default,
-                ResourceStates::CommonOrPresent,
+                ResourceStates::Common,
             )
             .expect("Cannot create default buffer");
 
@@ -579,7 +587,7 @@ impl HelloTriangleSample {
         HelloTriangleSample::add_transition(
             &self.command_list,
             &default_buffer,
-            ResourceStates::CommonOrPresent,
+            ResourceStates::Common,
             ResourceStates::CopyDest,
         );
 
