@@ -612,7 +612,7 @@ impl Pipeline {
                             .set_width(WINDOW_WIDTH.into())
                             .set_height(WINDOW_HEIGHT.into())
                             .set_flags(ResourceFlags::AllowRenderTarget),
-                        ResourceStates::CommonOrPresent,
+                        ResourceStates::Common,
                         None,
                     )
                     .expect("Cannot create render target on secondary adapter");
@@ -643,7 +643,7 @@ impl Pipeline {
                     &HeapProperties::default().set_heap_type(HeapType::Default),
                     HeapFlags::None,
                     &intermediate_render_target_desc,
-                    ResourceStates::CommonOrPresent,
+                    ResourceStates::Common,
                     None,
                 )
                 .expect("Cannot create intermediate render target on secondary adapter");
@@ -911,7 +911,7 @@ impl Pipeline {
 
             let src = TextureCopyLocation::new_placed_footprint(
                 &self.cross_adapter_resources[adapter_idx][self.frame_index],
-                &texture_layout[0],
+                texture_layout[0],
             );
 
             let resource_box = Box::default()
@@ -921,11 +921,11 @@ impl Pipeline {
                 .set_bottom(u32::from(WINDOW_HEIGHT));
 
             self.direct_command_lists[adapter_idx].copy_texture_region(
-                &dest,
+                dest,
                 0,
                 0,
                 0,
-                &src,
+                src,
                 Some(&resource_box),
             );
 
@@ -1029,7 +1029,7 @@ impl Pipeline {
                         .set_resource(
                             &self.render_targets[adapter_idx][self.frame_index],
                         )
-                        .set_state_before(ResourceStates::CommonOrPresent)
+                        .set_state_before(ResourceStates::Common)
                         .set_state_after(ResourceStates::RenderTarget),
                 ),
                 ResourceBarrier::new_transition(
@@ -1069,7 +1069,7 @@ impl Pipeline {
                         &self.render_targets[adapter_idx][self.frame_index],
                     )
                     .set_state_before(ResourceStates::RenderTarget)
-                    .set_state_after(ResourceStates::CommonOrPresent),
+                    .set_state_after(ResourceStates::Common),
             )),
         );
 
@@ -1103,8 +1103,8 @@ impl Pipeline {
             .expect("Cannot reset copy command list on primary adapter");
         if self.cross_adapter_textures_supported {
             self.copy_command_list.copy_resource(
-                &self.cross_adapter_resources[adapter_idx][self.frame_index],
                 &self.render_targets[adapter_idx][self.frame_index],
+                &self.cross_adapter_resources[adapter_idx][self.frame_index],
             );
         } else {
             let render_target_desc =
@@ -1114,7 +1114,7 @@ impl Pipeline {
 
             let dest = TextureCopyLocation::new_placed_footprint(
                 &self.cross_adapter_resources[adapter_idx][self.frame_index],
-                &render_target_layout[0],
+                render_target_layout[0],
             );
 
             let src = TextureCopyLocation::new_subresource_index(
@@ -1129,11 +1129,11 @@ impl Pipeline {
                 .set_bottom(u32::from(WINDOW_HEIGHT));
 
             self.copy_command_list.copy_texture_region(
-                &dest,
+                dest,
                 0,
                 0,
                 0,
-                &src,
+                src,
                 Some(&resource_box),
             );
         }
@@ -1178,7 +1178,7 @@ impl Pipeline {
                     .set_resource(
                         &self.render_targets[adapter_idx][self.frame_index],
                     )
-                    .set_state_before(ResourceStates::CommonOrPresent)
+                    .set_state_before(ResourceStates::Common)
                     .set_state_after(ResourceStates::RenderTarget),
             )),
         );
@@ -1251,7 +1251,7 @@ impl Pipeline {
                         &self.render_targets[adapter_idx][self.frame_index],
                     )
                     .set_state_before(ResourceStates::RenderTarget)
-                    .set_state_after(ResourceStates::CommonOrPresent),
+                    .set_state_after(ResourceStates::Common),
             )),
         );
 
@@ -2147,14 +2147,13 @@ fn create_psos(
     .expect("Cannot compile blur pixel shader V");
 
     let blur_input_layout = BlurVertex::make_desc();
-    let blur_layout = InputLayoutDesc::default().from_input_elements(&blur_input_layout);
+    let blur_layout =
+        InputLayoutDesc::default().from_input_elements(&blur_input_layout);
     let blur_vs_bytecode = ShaderBytecode::from_bytes(&blur_vertex_shader);
     let blur_ps_bytecode_u = ShaderBytecode::from_bytes(&blur_pixel_shader_u);
     let blur_ps_bytecode_v = ShaderBytecode::from_bytes(&blur_pixel_shader_v);
     let blur_pso_desc_u = GraphicsPipelineStateDesc::default()
-        .set_input_layout(
-            &blur_layout,
-        )
+        .set_input_layout(&blur_layout)
         .set_root_signature(blur_root_signature)
         .set_vs_bytecode(&blur_vs_bytecode)
         .set_ps_bytecode(&blur_ps_bytecode_u)
@@ -2174,9 +2173,7 @@ fn create_psos(
     trace!("Created blur PSO U");
 
     let blur_pso_desc_v = GraphicsPipelineStateDesc::default()
-        .set_input_layout(
-            &blur_layout,
-        )
+        .set_input_layout(&blur_layout)
         .set_root_signature(&blur_root_signature)
         .set_vs_bytecode(&blur_vs_bytecode)
         .set_ps_bytecode(&blur_ps_bytecode_v)
@@ -2248,6 +2245,8 @@ fn create_root_signatures(
                 DescriptorRangeOffset::append(),
             );
 
+        let descriptor_table = RootDescriptorTable::default()
+            .set_descriptor_ranges(slice::from_ref(&range));
         let blur_root_parameters = [
             RootParameter::default()
                 .new_descriptor(
@@ -2258,10 +2257,7 @@ fn create_root_signatures(
                 )
                 .set_shader_visibility(ShaderVisibility::Pixel),
             RootParameter::default()
-                .new_descriptor_table(
-                    &RootDescriptorTable::default()
-                        .set_descriptor_ranges(slice::from_ref(&range)),
-                )
+                .new_descriptor_table(&descriptor_table)
                 .set_shader_visibility(ShaderVisibility::Pixel),
             RootParameter::default()
                 .new_descriptor(
@@ -2419,7 +2415,7 @@ fn create_frame_resources(
                                 .set_heap_type(HeapType::Default),
                             HeapFlags::None,
                             &render_target_desc,
-                            ResourceStates::CommonOrPresent,
+                            ResourceStates::Common,
                             Some(&clear_value),
                         )
                         .expect("Cannot create render target"),
@@ -2546,7 +2542,7 @@ fn create_descriptor_heaps(
         let current_heap = devices[device_idx]
             .create_descriptor_heap(
                 &DescriptorHeapDesc::default()
-                    .set_heap_type(DescriptorHeapType::RTV)
+                    .set_heap_type(DescriptorHeapType::Rtv)
                     .set_num_descriptors(num_descriptors as u32),
             )
             .expect("Cannot create RTV heap");
@@ -2562,7 +2558,7 @@ fn create_descriptor_heaps(
     let dsv_heap = devices[0]
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::DSV)
+                .set_heap_type(DescriptorHeapType::Dsv)
                 .set_num_descriptors(1),
         )
         .expect("Cannot create DSV heap");
@@ -2573,7 +2569,7 @@ fn create_descriptor_heaps(
     let cbv_srv_heap = devices[1]
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::CBV_SRV_UAV)
+                .set_heap_type(DescriptorHeapType::CbvSrvUav)
                 .set_num_descriptors(FRAMES_IN_FLIGHT as u32 + 1)
                 .set_flags(DescriptorHeapFlags::ShaderVisible),
         )
