@@ -1,6 +1,6 @@
-use log::warn;
+use log::{trace, warn};
 use std::default::Default;
-use std::ffi::{CString, c_void};
+use std::ffi::{c_void, CString};
 use std::os::raw::c_char;
 use std::{slice, str};
 use winapi::shared::winerror;
@@ -24,10 +24,6 @@ pub use struct_wrappers::*;
 mod enum_wrappers;
 pub use enum_wrappers::*;
 
-// ToDo: operator? instead of .expect
-// ToDo: clean up redundant mut's in signatures
-// ToDo: remove D3D from type names?? (move to module?)
-
 // ToDo: macro?
 fn cast_to_ppv<T>(pointer: &mut *mut T) -> *mut *mut std::ffi::c_void {
     pointer as *mut *mut T as *mut *mut std::ffi::c_void
@@ -340,8 +336,9 @@ pub fn d3d_enable_experimental_shader_models() -> DxResult<()> {
     }
 }
 
+#[derive(Debug)]
 pub struct Debug {
-    this: *mut ID3D12Debug5,
+    pub this: *mut ID3D12Debug5,
 }
 impl_com_object_refcount_unnamed!(Debug);
 impl_com_object_clone_drop!(Debug);
@@ -374,8 +371,9 @@ impl Debug {
     }
 }
 
+#[derive(Debug)]
 pub struct InfoQueue {
-    this: *mut ID3D12InfoQueue1,
+    pub this: *mut ID3D12InfoQueue1,
 }
 impl_com_object_refcount_unnamed!(InfoQueue);
 impl_com_object_clone_drop!(InfoQueue);
@@ -489,8 +487,9 @@ impl InfoQueue {
     }
 }
 
+#[derive(Debug)]
 pub struct DebugDevice {
-    this: *mut ID3D12DebugDevice,
+    pub this: *mut ID3D12DebugDevice,
 }
 impl_com_object_refcount_unnamed!(DebugDevice);
 impl_com_object_clone_drop!(DebugDevice);
@@ -529,8 +528,9 @@ impl DebugDevice {
     }
 }
 
+#[derive(Debug)]
 pub struct Factory {
-    this: *mut IDXGIFactory6,
+    pub this: *mut IDXGIFactory6,
 }
 impl_com_object_refcount_unnamed!(Factory);
 impl_com_object_clone_drop!(Factory);
@@ -685,8 +685,9 @@ impl Factory {
     }
 }
 
+#[derive(Debug)]
 pub struct Adapter {
-    this: *mut IDXGIAdapter3,
+    pub this: *mut IDXGIAdapter3,
 }
 impl_com_object_refcount_unnamed!(Adapter);
 impl_com_object_clone_drop!(Adapter);
@@ -701,8 +702,9 @@ impl Adapter {
     }
 }
 
+#[derive(Debug)]
 pub struct Device {
-    this: *mut ID3D12Device2,
+    pub this: *mut ID3D12Device2,
 }
 impl_com_object_refcount_unnamed!(Device);
 impl_com_object_clone_drop!(Device);
@@ -820,7 +822,7 @@ impl Device {
                 &heap_props.0,
                 heap_flags.bits(),
                 &resource_desc.0,
-                initial_state as i32,
+                initial_state.bits(),
                 match optimized_clear_value {
                     Some(clear_value) => {
                         &clear_value.0
@@ -1004,7 +1006,7 @@ impl Device {
                 heap.this,
                 heap_offset.0,
                 &resource_desc.0,
-                initial_state as i32,
+                initial_state.bits(),
                 match optimized_clear_value {
                     Some(clear_value) => {
                         &clear_value.0
@@ -1069,7 +1071,7 @@ impl Device {
                 self.this,
                 CreateReservedResource,
                 &resource_desc.0,
-                initial_state as i32,
+                initial_state.bits(),
                 match optimized_clear_value {
                     Some(clear_value) => {
                         &clear_value.0
@@ -1251,6 +1253,13 @@ impl Device {
         }
     }
 
+    pub fn get_device_removed_reason(&self) -> DxError {
+        unsafe {
+            let result = dx_call!(self.this, GetDeviceRemovedReason,);
+            DxError::new("GetDeviceRemovedReason", result)
+        }
+    }
+
     pub fn get_resource_allocation_info(
         &self,
         visible_mask: u32,
@@ -1357,8 +1366,9 @@ impl Device {
     }
 }
 
+#[derive(Debug)]
 pub struct DeviceChild {
-    this: *mut ID3D12DeviceChild,
+    pub this: *mut ID3D12DeviceChild,
 }
 impl_com_object_refcount_unnamed!(DeviceChild);
 impl_com_object_clone_drop!(DeviceChild);
@@ -1393,8 +1403,9 @@ impl From<Fence> for DeviceChild {
     }
 }
 
+#[derive(Debug)]
 pub struct CommandQueue {
-    this: *mut ID3D12CommandQueue,
+    pub this: *mut ID3D12CommandQueue,
 }
 impl_com_object_refcount_unnamed!(CommandQueue);
 impl_com_object_clone_drop!(CommandQueue);
@@ -1433,8 +1444,9 @@ impl CommandQueue {
     }
 }
 
+#[derive(Debug)]
 pub struct Swapchain {
-    this: *mut IDXGISwapChain4,
+    pub this: *mut IDXGISwapChain4,
 }
 impl_com_object_refcount_unnamed!(Swapchain);
 impl_com_object_clone_drop!(Swapchain);
@@ -1477,8 +1489,9 @@ impl Swapchain {
     }
 }
 
+#[derive(Debug)]
 pub struct DescriptorHeap {
-    this: *mut ID3D12DescriptorHeap,
+    pub this: *mut ID3D12DescriptorHeap,
     handle_size: u32, // it could be Bytes, but the latter is 64-bit, and
                       // since it doesn't leak into public interface, there isn't much sense in it
 }
@@ -1525,10 +1538,10 @@ impl DescriptorHeap {
     }
 }
 
-#[derive(Copy, Clone)]
+#[derive(Copy, Clone, Debug)]
 pub struct CpuDescriptorHandle {
-    hw_handle: D3D12_CPU_DESCRIPTOR_HANDLE,
-    handle_size: u32,
+    pub hw_handle: D3D12_CPU_DESCRIPTOR_HANDLE,
+    pub handle_size: u32,
 }
 
 impl CpuDescriptorHandle {
@@ -1543,10 +1556,10 @@ impl CpuDescriptorHandle {
     }
 }
 
-#[derive(Copy, Clone)]
+#[derive(Debug, Copy, Clone)]
 pub struct GpuDescriptorHandle {
-    hw_handle: D3D12_GPU_DESCRIPTOR_HANDLE,
-    handle_size: u32,
+    pub hw_handle: D3D12_GPU_DESCRIPTOR_HANDLE,
+    pub handle_size: u32,
 }
 
 impl GpuDescriptorHandle {
@@ -1560,8 +1573,9 @@ impl GpuDescriptorHandle {
     }
 }
 
+#[derive(Debug)]
 pub struct Resource {
-    this: *mut ID3D12Resource,
+    pub this: *mut ID3D12Resource,
 }
 impl_com_object_clone_drop!(Resource);
 impl_com_object_refcount_named!(Resource);
@@ -1651,8 +1665,9 @@ impl Resource {
     }
 }
 
+#[derive(Debug)]
 pub struct CommandAllocator {
-    this: *mut ID3D12CommandAllocator,
+    pub this: *mut ID3D12CommandAllocator,
 }
 impl_com_object_set_get_name!(CommandAllocator);
 impl_com_object_refcount_named!(CommandAllocator);
@@ -1667,8 +1682,9 @@ impl CommandAllocator {
 
 assert_eq_size!(CommandList, *mut ID3D12GraphicsCommandList6);
 
+#[derive(Debug)]
 pub struct CommandList {
-    this: *mut ID3D12GraphicsCommandList6,
+    pub this: *mut ID3D12GraphicsCommandList6,
 }
 impl_com_object_set_get_name!(CommandList);
 impl_com_object_refcount_named!(CommandList);
@@ -1758,17 +1774,17 @@ impl CommandList {
         }
     }
 
-    pub fn copy_resource(&self, source: &Resource, dest: &Resource) {
+    pub fn copy_resource(&self, dest: &Resource, source: &Resource) {
         unsafe { dx_call!(self.this, CopyResource, dest.this, source.this) }
     }
 
     pub fn copy_texture_region(
         &self,
-        dest_location: &TextureCopyLocation,
-        dest_x: u32, // ToDo: is it really u32?
+        dest_location: TextureCopyLocation,
+        dest_x: u32,
         dest_y: u32,
         dest_z: u32,
-        source_location: &TextureCopyLocation,
+        source_location: TextureCopyLocation,
         source_box: Option<&Box>,
     ) {
         unsafe {
@@ -1781,7 +1797,7 @@ impl CommandList {
                 dest_z,
                 &source_location.0,
                 match source_box {
-                    Some(&b) => &b.0,
+                    Some(b) => &b.0,
                     None => std::ptr::null_mut(),
                 }
             )
@@ -2223,7 +2239,7 @@ impl CommandList {
                     false => 0,
                 },
                 match depth_stencil {
-                    Some(depth_desc) => &depth_desc.hw_handle,
+                    Some(ref depth_desc) => &depth_desc.hw_handle,
                     None => std::ptr::null_mut(),
                 }
             )
@@ -2324,15 +2340,15 @@ impl CommandList {
                 );
                 let source_location = TextureCopyLocation::new_placed_footprint(
                     intermediate_resource,
-                    &layouts[i],
+                    layouts[i],
                 );
 
                 self.copy_texture_region(
-                    &dest_location,
+                    dest_location,
                     0,
                     0,
                     0,
-                    &source_location,
+                    source_location,
                     None,
                 );
             }
@@ -2414,8 +2430,9 @@ unsafe fn memcpy_subresource(
     }
 }
 
+#[derive(Debug)]
 pub struct Fence {
-    this: *mut ID3D12Fence,
+    pub this: *mut ID3D12Fence,
 }
 
 impl_com_object_set_get_name!(Fence);
@@ -2447,8 +2464,9 @@ impl Fence {
     }
 }
 
+#[derive(Debug)]
 pub struct Win32Event {
-    handle: HANDLE,
+    pub handle: HANDLE,
 }
 
 unsafe impl Send for Win32Event {}
@@ -2498,8 +2516,9 @@ impl Handle {
     }
 }
 
+#[derive(Debug)]
 pub struct RootSignature {
-    this: *mut ID3D12RootSignature,
+    pub this: *mut ID3D12RootSignature,
 }
 impl_com_object_refcount_unnamed!(RootSignature);
 impl_com_object_clone_drop!(RootSignature);
@@ -2535,8 +2554,9 @@ impl RootSignature {
     }
 }
 
+#[derive(Debug)]
 pub struct PipelineState {
-    this: *mut ID3D12PipelineState,
+    pub this: *mut ID3D12PipelineState,
 }
 impl_com_object_set_get_name!(PipelineState);
 impl_com_object_refcount_named!(PipelineState);
@@ -2544,8 +2564,9 @@ impl_com_object_clone_drop!(PipelineState);
 
 unsafe impl Send for PipelineState {}
 
+#[derive(Debug)]
 pub struct Blob {
-    this: *mut ID3DBlob,
+    pub this: *mut ID3DBlob,
 }
 impl_com_object_refcount_unnamed!(Blob);
 impl_com_object_clone_drop!(Blob);
@@ -2561,15 +2582,17 @@ impl Blob {
     }
 }
 
+#[derive(Debug)]
 pub struct QueryHeap {
-    this: *mut ID3D12QueryHeap,
+    pub this: *mut ID3D12QueryHeap,
 }
 impl_com_object_set_get_name!(QueryHeap);
 impl_com_object_refcount_named!(QueryHeap);
 impl_com_object_clone_drop!(QueryHeap);
 
+#[derive(Debug)]
 pub struct Heap {
-    this: *mut ID3D12Heap,
+    pub this: *mut ID3D12Heap,
 }
 impl_com_object_set_get_name!(Heap);
 impl_com_object_refcount_named!(Heap);
